Re: x86: sort reboot DMI quirks by vendor.

2013-10-02 Thread Ingo Molnar

* Dave Jones  wrote:

> Grouping them by vendor should make it easier to spot duplicates.
> 
> Signed-off-by: Dave Jones 

Thanks Dave!

Ingo
--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/


Re: x86: sort reboot DMI quirks by vendor.

2013-10-02 Thread Ingo Molnar

* Dave Jones da...@redhat.com wrote:

 Grouping them by vendor should make it easier to spot duplicates.
 
 Signed-off-by: Dave Jones da...@fedoraproject.org

Thanks Dave!

Ingo
--
To unsubscribe from this list: send the line unsubscribe linux-kernel in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/


Re: x86: sort reboot DMI quirks by vendor.

2013-10-01 Thread Dave Jones
Grouping them by vendor should make it easier to spot duplicates.

Signed-off-by: Dave Jones 

diff --git a/arch/x86/kernel/reboot.c b/arch/x86/kernel/reboot.c
index d9333a4..7692520 100644
--- a/arch/x86/kernel/reboot.c
+++ b/arch/x86/kernel/reboot.c
@@ -136,236 +136,248 @@ static int __init set_kbd_reboot(const struct 
dmi_system_id *d)
  * This is a single dmi_table handling all reboot quirks.
  */
 static struct dmi_system_id __initdata reboot_dmi_table[] = {
-   {   /* Handle problems with rebooting on Dell E520's */
-   .callback = set_bios_reboot,
-   .ident = "Dell E520",
+
+   /* Acer */
+   {   /* Handle reboot issue on Acer Aspire one */
+   .callback = set_kbd_reboot,
+   .ident = "Acer Aspire One A110",
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, "Dell Inc."),
-   DMI_MATCH(DMI_PRODUCT_NAME, "Dell DM061"),
+   DMI_MATCH(DMI_SYS_VENDOR, "Acer"),
+   DMI_MATCH(DMI_PRODUCT_NAME, "AOA110"),
},
},
-   {   /* Handle problems with rebooting on Dell 1300's */
-   .callback = set_bios_reboot,
-   .ident = "Dell PowerEdge 1300",
+
+   /* Apple */
+   {   /* Handle problems with rebooting on Apple MacBook5 */
+   .callback = set_pci_reboot,
+   .ident = "Apple MacBook5",
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, "Dell Computer Corporation"),
-   DMI_MATCH(DMI_PRODUCT_NAME, "PowerEdge 1300/"),
+   DMI_MATCH(DMI_SYS_VENDOR, "Apple Inc."),
+   DMI_MATCH(DMI_PRODUCT_NAME, "MacBook5"),
},
},
-   {   /* Handle problems with rebooting on Dell 300's */
-   .callback = set_bios_reboot,
-   .ident = "Dell PowerEdge 300",
+   {   /* Handle problems with rebooting on Apple MacBookPro5 */
+   .callback = set_pci_reboot,
+   .ident = "Apple MacBookPro5",
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, "Dell Computer Corporation"),
-   DMI_MATCH(DMI_PRODUCT_NAME, "PowerEdge 300/"),
+   DMI_MATCH(DMI_SYS_VENDOR, "Apple Inc."),
+   DMI_MATCH(DMI_PRODUCT_NAME, "MacBookPro5"),
},
},
-   {   /* Handle problems with rebooting on Dell Optiplex 745's SFF */
-   .callback = set_bios_reboot,
-   .ident = "Dell OptiPlex 745",
+   {   /* Handle problems with rebooting on Apple Macmini3,1 */
+   .callback = set_pci_reboot,
+   .ident = "Apple Macmini3,1",
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, "Dell Inc."),
-   DMI_MATCH(DMI_PRODUCT_NAME, "OptiPlex 745"),
+   DMI_MATCH(DMI_SYS_VENDOR, "Apple Inc."),
+   DMI_MATCH(DMI_PRODUCT_NAME, "Macmini3,1"),
},
},
-   {   /* Handle problems with rebooting on Dell Optiplex 745's DFF */
-   .callback = set_bios_reboot,
-   .ident = "Dell OptiPlex 745",
+   {   /* Handle problems with rebooting on the iMac9,1. */
+   .callback = set_pci_reboot,
+   .ident = "Apple iMac9,1",
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, "Dell Inc."),
-   DMI_MATCH(DMI_PRODUCT_NAME, "OptiPlex 745"),
-   DMI_MATCH(DMI_BOARD_NAME, "0MM599"),
+   DMI_MATCH(DMI_SYS_VENDOR, "Apple Inc."),
+   DMI_MATCH(DMI_PRODUCT_NAME, "iMac9,1"),
},
},
-   {   /* Handle problems with rebooting on Dell Optiplex 745 with 
0KW626 */
+
+   /* ASUS */
+   {   /* Handle problems with rebooting on ASUS P4S800 */
.callback = set_bios_reboot,
-   .ident = "Dell OptiPlex 745",
+   .ident = "ASUS P4S800",
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, "Dell Inc."),
-   DMI_MATCH(DMI_PRODUCT_NAME, "OptiPlex 745"),
-   DMI_MATCH(DMI_BOARD_NAME, "0KW626"),
+   DMI_MATCH(DMI_BOARD_VENDOR, "ASUSTeK Computer INC."),
+   DMI_MATCH(DMI_BOARD_NAME, "P4S800"),
},
},
-   {   /* Handle problems with rebooting on Dell Optiplex 330 with 
0KP561 */
+
+   /* Dell */
+   {   /* Handle problems with rebooting on Dell DXP061 */
.callback = set_bios_reboot,
-   .ident = "Dell OptiPlex 330",
+   .ident = "Dell DXP061",
.matches = {
DMI_MATCH(DMI_SYS_VENDOR, "Dell Inc."),
-   DMI_MATCH(DMI_PRODUCT_NAME, "OptiPlex 330"),
-   

Re: x86: sort reboot DMI quirks by vendor.

2013-10-01 Thread Dave Jones
Grouping them by vendor should make it easier to spot duplicates.

Signed-off-by: Dave Jones da...@fedoraproject.org

diff --git a/arch/x86/kernel/reboot.c b/arch/x86/kernel/reboot.c
index d9333a4..7692520 100644
--- a/arch/x86/kernel/reboot.c
+++ b/arch/x86/kernel/reboot.c
@@ -136,236 +136,248 @@ static int __init set_kbd_reboot(const struct 
dmi_system_id *d)
  * This is a single dmi_table handling all reboot quirks.
  */
 static struct dmi_system_id __initdata reboot_dmi_table[] = {
-   {   /* Handle problems with rebooting on Dell E520's */
-   .callback = set_bios_reboot,
-   .ident = Dell E520,
+
+   /* Acer */
+   {   /* Handle reboot issue on Acer Aspire one */
+   .callback = set_kbd_reboot,
+   .ident = Acer Aspire One A110,
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, Dell Inc.),
-   DMI_MATCH(DMI_PRODUCT_NAME, Dell DM061),
+   DMI_MATCH(DMI_SYS_VENDOR, Acer),
+   DMI_MATCH(DMI_PRODUCT_NAME, AOA110),
},
},
-   {   /* Handle problems with rebooting on Dell 1300's */
-   .callback = set_bios_reboot,
-   .ident = Dell PowerEdge 1300,
+
+   /* Apple */
+   {   /* Handle problems with rebooting on Apple MacBook5 */
+   .callback = set_pci_reboot,
+   .ident = Apple MacBook5,
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, Dell Computer Corporation),
-   DMI_MATCH(DMI_PRODUCT_NAME, PowerEdge 1300/),
+   DMI_MATCH(DMI_SYS_VENDOR, Apple Inc.),
+   DMI_MATCH(DMI_PRODUCT_NAME, MacBook5),
},
},
-   {   /* Handle problems with rebooting on Dell 300's */
-   .callback = set_bios_reboot,
-   .ident = Dell PowerEdge 300,
+   {   /* Handle problems with rebooting on Apple MacBookPro5 */
+   .callback = set_pci_reboot,
+   .ident = Apple MacBookPro5,
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, Dell Computer Corporation),
-   DMI_MATCH(DMI_PRODUCT_NAME, PowerEdge 300/),
+   DMI_MATCH(DMI_SYS_VENDOR, Apple Inc.),
+   DMI_MATCH(DMI_PRODUCT_NAME, MacBookPro5),
},
},
-   {   /* Handle problems with rebooting on Dell Optiplex 745's SFF */
-   .callback = set_bios_reboot,
-   .ident = Dell OptiPlex 745,
+   {   /* Handle problems with rebooting on Apple Macmini3,1 */
+   .callback = set_pci_reboot,
+   .ident = Apple Macmini3,1,
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, Dell Inc.),
-   DMI_MATCH(DMI_PRODUCT_NAME, OptiPlex 745),
+   DMI_MATCH(DMI_SYS_VENDOR, Apple Inc.),
+   DMI_MATCH(DMI_PRODUCT_NAME, Macmini3,1),
},
},
-   {   /* Handle problems with rebooting on Dell Optiplex 745's DFF */
-   .callback = set_bios_reboot,
-   .ident = Dell OptiPlex 745,
+   {   /* Handle problems with rebooting on the iMac9,1. */
+   .callback = set_pci_reboot,
+   .ident = Apple iMac9,1,
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, Dell Inc.),
-   DMI_MATCH(DMI_PRODUCT_NAME, OptiPlex 745),
-   DMI_MATCH(DMI_BOARD_NAME, 0MM599),
+   DMI_MATCH(DMI_SYS_VENDOR, Apple Inc.),
+   DMI_MATCH(DMI_PRODUCT_NAME, iMac9,1),
},
},
-   {   /* Handle problems with rebooting on Dell Optiplex 745 with 
0KW626 */
+
+   /* ASUS */
+   {   /* Handle problems with rebooting on ASUS P4S800 */
.callback = set_bios_reboot,
-   .ident = Dell OptiPlex 745,
+   .ident = ASUS P4S800,
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, Dell Inc.),
-   DMI_MATCH(DMI_PRODUCT_NAME, OptiPlex 745),
-   DMI_MATCH(DMI_BOARD_NAME, 0KW626),
+   DMI_MATCH(DMI_BOARD_VENDOR, ASUSTeK Computer INC.),
+   DMI_MATCH(DMI_BOARD_NAME, P4S800),
},
},
-   {   /* Handle problems with rebooting on Dell Optiplex 330 with 
0KP561 */
+
+   /* Dell */
+   {   /* Handle problems with rebooting on Dell DXP061 */
.callback = set_bios_reboot,
-   .ident = Dell OptiPlex 330,
+   .ident = Dell DXP061,
.matches = {
DMI_MATCH(DMI_SYS_VENDOR, Dell Inc.),
-   DMI_MATCH(DMI_PRODUCT_NAME, OptiPlex 330),
-   DMI_MATCH(DMI_BOARD_NAME, 0KP561),
+ 

Re: x86: sort reboot DMI quirks by vendor.

2013-09-28 Thread Ingo Molnar

* Dave Jones  wrote:

> Grouping them by vendor should make it easier to spot duplicates.
> 
> Signed-off-by: Dave Jones 
> 
> diff --git a/arch/x86/kernel/reboot.c b/arch/x86/kernel/reboot.c
> index e643e74..12521b2 100644
> --- a/arch/x86/kernel/reboot.c
> +++ b/arch/x86/kernel/reboot.c

Could you please send this patch against latest -tip? It already has 
changes to the quirks, in the tip:x86/reboot tree (also merged into 
tip:master), which conflict with this change.

Thanks,

Ingo
--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/


Re: x86: sort reboot DMI quirks by vendor.

2013-09-28 Thread Ingo Molnar

* Dave Jones da...@redhat.com wrote:

 Grouping them by vendor should make it easier to spot duplicates.
 
 Signed-off-by: Dave Jones da...@fedoraproject.org
 
 diff --git a/arch/x86/kernel/reboot.c b/arch/x86/kernel/reboot.c
 index e643e74..12521b2 100644
 --- a/arch/x86/kernel/reboot.c
 +++ b/arch/x86/kernel/reboot.c

Could you please send this patch against latest -tip? It already has 
changes to the quirks, in the tip:x86/reboot tree (also merged into 
tip:master), which conflict with this change.

Thanks,

Ingo
--
To unsubscribe from this list: send the line unsubscribe linux-kernel in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/


x86: sort reboot DMI quirks by vendor.

2013-09-27 Thread Dave Jones
Grouping them by vendor should make it easier to spot duplicates.

Signed-off-by: Dave Jones 

diff --git a/arch/x86/kernel/reboot.c b/arch/x86/kernel/reboot.c
index e643e74..12521b2 100644
--- a/arch/x86/kernel/reboot.c
+++ b/arch/x86/kernel/reboot.c
@@ -136,244 +136,255 @@ static int __init set_kbd_reboot(const struct 
dmi_system_id *d)
  * This is a single dmi_table handling all reboot quirks.
  */
 static struct dmi_system_id __initdata reboot_dmi_table[] = {
-   {   /* Handle problems with rebooting on Dell E520's */
-   .callback = set_bios_reboot,
-   .ident = "Dell E520",
+   /* Acer */
+   {   /* Handle reboot issue on Acer Aspire one */
+   .callback = set_kbd_reboot,
+   .ident = "Acer Aspire One A110",
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, "Dell Inc."),
-   DMI_MATCH(DMI_PRODUCT_NAME, "Dell DM061"),
+   DMI_MATCH(DMI_SYS_VENDOR, "Acer"),
+   DMI_MATCH(DMI_PRODUCT_NAME, "AOA110"),
},
},
-   {   /* Handle problems with rebooting on Dell 1300's */
+
+   /* ASUS */
+   {   /* Handle problems with rebooting on ASUS P4S800 */
.callback = set_bios_reboot,
-   .ident = "Dell PowerEdge 1300",
+   .ident = "ASUS P4S800",
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, "Dell Computer Corporation"),
-   DMI_MATCH(DMI_PRODUCT_NAME, "PowerEdge 1300/"),
+   DMI_MATCH(DMI_BOARD_VENDOR, "ASUSTeK Computer INC."),
+   DMI_MATCH(DMI_BOARD_NAME, "P4S800"),
},
},
-   {   /* Handle problems with rebooting on Dell 300's */
-   .callback = set_bios_reboot,
-   .ident = "Dell PowerEdge 300",
+
+   /* Apple */
+   {   /* Handle problems with rebooting on Apple MacBook5 */
+   .callback = set_pci_reboot,
+   .ident = "Apple MacBook5",
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, "Dell Computer Corporation"),
-   DMI_MATCH(DMI_PRODUCT_NAME, "PowerEdge 300/"),
+   DMI_MATCH(DMI_SYS_VENDOR, "Apple Inc."),
+   DMI_MATCH(DMI_PRODUCT_NAME, "MacBook5"),
},
},
-   {   /* Handle problems with rebooting on Dell Optiplex 745's SFF */
-   .callback = set_bios_reboot,
-   .ident = "Dell OptiPlex 745",
+   {   /* Handle problems with rebooting on Apple MacBookPro5 */
+   .callback = set_pci_reboot,
+   .ident = "Apple MacBookPro5",
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, "Dell Inc."),
-   DMI_MATCH(DMI_PRODUCT_NAME, "OptiPlex 745"),
+   DMI_MATCH(DMI_SYS_VENDOR, "Apple Inc."),
+   DMI_MATCH(DMI_PRODUCT_NAME, "MacBookPro5"),
},
},
-   {   /* Handle problems with rebooting on Dell Optiplex 745's DFF */
-   .callback = set_bios_reboot,
-   .ident = "Dell OptiPlex 745",
+   {   /* Handle problems with rebooting on Apple Macmini3,1 */
+   .callback = set_pci_reboot,
+   .ident = "Apple Macmini3,1",
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, "Dell Inc."),
-   DMI_MATCH(DMI_PRODUCT_NAME, "OptiPlex 745"),
-   DMI_MATCH(DMI_BOARD_NAME, "0MM599"),
+   DMI_MATCH(DMI_SYS_VENDOR, "Apple Inc."),
+   DMI_MATCH(DMI_PRODUCT_NAME, "Macmini3,1"),
},
},
-   {   /* Handle problems with rebooting on Dell Optiplex 745 with 
0KW626 */
-   .callback = set_bios_reboot,
-   .ident = "Dell OptiPlex 745",
+   {   /* Handle problems with rebooting on the iMac9,1. */
+   .callback = set_pci_reboot,
+   .ident = "Apple iMac9,1",
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, "Dell Inc."),
-   DMI_MATCH(DMI_PRODUCT_NAME, "OptiPlex 745"),
-   DMI_MATCH(DMI_BOARD_NAME, "0KW626"),
+   DMI_MATCH(DMI_SYS_VENDOR, "Apple Inc."),
+   DMI_MATCH(DMI_PRODUCT_NAME, "iMac9,1"),
},
},
-   {   /* Handle problems with rebooting on Dell Optiplex 330 with 
0KP561 */
+
+   /* Dell */
+   {   /* Handle problems with rebooting on Dell DXP061 */
.callback = set_bios_reboot,
-   .ident = "Dell OptiPlex 330",
+   .ident = "Dell DXP061",
.matches = {
DMI_MATCH(DMI_SYS_VENDOR, "Dell Inc."),
-   DMI_MATCH(DMI_PRODUCT_NAME, "OptiPlex 330"),
- 

x86: sort reboot DMI quirks by vendor.

2013-09-27 Thread Dave Jones
Grouping them by vendor should make it easier to spot duplicates.

Signed-off-by: Dave Jones da...@fedoraproject.org

diff --git a/arch/x86/kernel/reboot.c b/arch/x86/kernel/reboot.c
index e643e74..12521b2 100644
--- a/arch/x86/kernel/reboot.c
+++ b/arch/x86/kernel/reboot.c
@@ -136,244 +136,255 @@ static int __init set_kbd_reboot(const struct 
dmi_system_id *d)
  * This is a single dmi_table handling all reboot quirks.
  */
 static struct dmi_system_id __initdata reboot_dmi_table[] = {
-   {   /* Handle problems with rebooting on Dell E520's */
-   .callback = set_bios_reboot,
-   .ident = Dell E520,
+   /* Acer */
+   {   /* Handle reboot issue on Acer Aspire one */
+   .callback = set_kbd_reboot,
+   .ident = Acer Aspire One A110,
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, Dell Inc.),
-   DMI_MATCH(DMI_PRODUCT_NAME, Dell DM061),
+   DMI_MATCH(DMI_SYS_VENDOR, Acer),
+   DMI_MATCH(DMI_PRODUCT_NAME, AOA110),
},
},
-   {   /* Handle problems with rebooting on Dell 1300's */
+
+   /* ASUS */
+   {   /* Handle problems with rebooting on ASUS P4S800 */
.callback = set_bios_reboot,
-   .ident = Dell PowerEdge 1300,
+   .ident = ASUS P4S800,
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, Dell Computer Corporation),
-   DMI_MATCH(DMI_PRODUCT_NAME, PowerEdge 1300/),
+   DMI_MATCH(DMI_BOARD_VENDOR, ASUSTeK Computer INC.),
+   DMI_MATCH(DMI_BOARD_NAME, P4S800),
},
},
-   {   /* Handle problems with rebooting on Dell 300's */
-   .callback = set_bios_reboot,
-   .ident = Dell PowerEdge 300,
+
+   /* Apple */
+   {   /* Handle problems with rebooting on Apple MacBook5 */
+   .callback = set_pci_reboot,
+   .ident = Apple MacBook5,
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, Dell Computer Corporation),
-   DMI_MATCH(DMI_PRODUCT_NAME, PowerEdge 300/),
+   DMI_MATCH(DMI_SYS_VENDOR, Apple Inc.),
+   DMI_MATCH(DMI_PRODUCT_NAME, MacBook5),
},
},
-   {   /* Handle problems with rebooting on Dell Optiplex 745's SFF */
-   .callback = set_bios_reboot,
-   .ident = Dell OptiPlex 745,
+   {   /* Handle problems with rebooting on Apple MacBookPro5 */
+   .callback = set_pci_reboot,
+   .ident = Apple MacBookPro5,
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, Dell Inc.),
-   DMI_MATCH(DMI_PRODUCT_NAME, OptiPlex 745),
+   DMI_MATCH(DMI_SYS_VENDOR, Apple Inc.),
+   DMI_MATCH(DMI_PRODUCT_NAME, MacBookPro5),
},
},
-   {   /* Handle problems with rebooting on Dell Optiplex 745's DFF */
-   .callback = set_bios_reboot,
-   .ident = Dell OptiPlex 745,
+   {   /* Handle problems with rebooting on Apple Macmini3,1 */
+   .callback = set_pci_reboot,
+   .ident = Apple Macmini3,1,
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, Dell Inc.),
-   DMI_MATCH(DMI_PRODUCT_NAME, OptiPlex 745),
-   DMI_MATCH(DMI_BOARD_NAME, 0MM599),
+   DMI_MATCH(DMI_SYS_VENDOR, Apple Inc.),
+   DMI_MATCH(DMI_PRODUCT_NAME, Macmini3,1),
},
},
-   {   /* Handle problems with rebooting on Dell Optiplex 745 with 
0KW626 */
-   .callback = set_bios_reboot,
-   .ident = Dell OptiPlex 745,
+   {   /* Handle problems with rebooting on the iMac9,1. */
+   .callback = set_pci_reboot,
+   .ident = Apple iMac9,1,
.matches = {
-   DMI_MATCH(DMI_SYS_VENDOR, Dell Inc.),
-   DMI_MATCH(DMI_PRODUCT_NAME, OptiPlex 745),
-   DMI_MATCH(DMI_BOARD_NAME, 0KW626),
+   DMI_MATCH(DMI_SYS_VENDOR, Apple Inc.),
+   DMI_MATCH(DMI_PRODUCT_NAME, iMac9,1),
},
},
-   {   /* Handle problems with rebooting on Dell Optiplex 330 with 
0KP561 */
+
+   /* Dell */
+   {   /* Handle problems with rebooting on Dell DXP061 */
.callback = set_bios_reboot,
-   .ident = Dell OptiPlex 330,
+   .ident = Dell DXP061,
.matches = {
DMI_MATCH(DMI_SYS_VENDOR, Dell Inc.),
-   DMI_MATCH(DMI_PRODUCT_NAME, OptiPlex 330),
-   DMI_MATCH(DMI_BOARD_NAME, 0KP561),
+